@@ -12,8 +12,10 @@ get_downloaded_datasets <- function(data_path = NULL) {
     data_path <- get_data_path()
   }
   all_nc_files <- list.files(data_path)
-  files_subset <- getOption("pastclim.dataset_list")[getOption("pastclim.dataset_list")$file_name %in%
-    all_nc_files, ]
+  files_subset <- getOption("pastclim.dataset_list")[
+    getOption("pastclim.dataset_list")$file_name %in%
+      all_nc_files,
+  ]
   downloaded_vars <- list()
   for (dataset in unique(files_subset$dataset)) {
     downloaded_vars[[dataset]] <- files_subset[
