@@ -20,8 +20,9 @@ get_mis_time_steps <- function(mis, dataset, path_to_nc = NULL) {
   }
 
   time_steps <- get_time_bp_steps(dataset = dataset, path_to_nc = path_to_nc)
-  mis_time_steps <- time_steps[time_steps > (mis_boundaries[mis_boundaries$mis
-  == mis, "start"] * 1000) &
-    time_steps <= (mis_boundaries[mis_boundaries$mis == mis, "end"] * 1000)]
+  mis_time_steps <- time_steps[
+    time_steps > (mis_boundaries[mis_boundaries$mis == mis, "start"] * 1000) &
+      time_steps <= (mis_boundaries[mis_boundaries$mis == mis, "end"] * 1000)
+  ]
   return(mis_time_steps)
 }
