@@ -6,12 +6,12 @@
 #' different reconstructions.
 #'
 #' @param dataset string defining dataset to be downloaded (a list of possible
-#' values can be obtained with [list_available_datasets()]).
+#'   values can be obtained with [list_available_datasets()]).
 #' @param path_to_nc the path to the custom nc file containing the palaeoclimate
-#' reconstructions. If a custom nc file is given, 'details', 'annual' and 'monthly'
-#' are ignored
-#' @param details boolean determining whether the output should include information
-#' including long names of variables and their units.
+#'   reconstructions. If a custom nc file is given, 'details', 'annual' and
+#'   'monthly' are ignored
+#' @param details boolean determining whether the output should include
+#'   information including long names of variables and their units.
 #' @param annual boolean to show annual variables
 #' @param monthly boolean to show monthly variables
 #' @returns a vector of variable names
@@ -25,11 +25,9 @@ get_vars_for_dataset <- function(dataset, path_to_nc = NULL, details = FALSE,
       stop("path_to_nc should only be set for 'custom' dataset")
     }
     check_available_dataset(dataset)
-    variable_info <- getOption("pastclim.dataset_list")[getOption("pastclim.dataset_list")$dataset == dataset, ]
-    # select variable types
-    # if (!all(monthly, annual)){
-    #   variable_info <- variable_info[variable_info$monthly==monthly,]
-    # }
+    variable_info <- getOption("pastclim.dataset_list")[
+      getOption("pastclim.dataset_list")$dataset == dataset,
+    ]
     if (!monthly) {
       variable_info <- variable_info[variable_info$monthly == FALSE, ]
     }
@@ -47,7 +45,6 @@ get_vars_for_dataset <- function(dataset, path_to_nc = NULL, details = FALSE,
     }
     nc_in <- ncdf4::nc_open(path_to_nc)
     if (!details) {
-      vars <- names(nc_in$var)
       ncdf4::nc_close(nc_in)
       return(names(nc_in$var))
     } else {
@@ -77,10 +74,12 @@ get_vars_for_dataset <- function(dataset, path_to_nc = NULL, details = FALSE,
 check_available_variable <- function(variable, dataset) {
   # check that the variable is available for this dataset
   if (!all(variable %in% get_vars_for_dataset(dataset, monthly = TRUE))) {
-    missing_variables <- variable[!variable %in% get_vars_for_dataset(dataset,
-      annual = TRUE,
-      monthly = TRUE
-    )]
+    missing_variables <- variable[
+      !variable %in% get_vars_for_dataset(dataset,
+        annual = TRUE,
+        monthly = TRUE
+      )
+    ]
     stop(
       paste(missing_variables, collapse = ", "), " not available for ", dataset,
       "; available variables are ",
@@ -101,6 +100,8 @@ check_available_variable <- function(variable, dataset) {
 #' @keywords internal
 
 get_varname <- function(variable, dataset) {
-  return(getOption("pastclim.dataset_list")$ncvar[getOption("pastclim.dataset_list")$variable == variable &
-    getOption("pastclim.dataset_list")$dataset == dataset])
+  return(getOption("pastclim.dataset_list")$ncvar[
+    getOption("pastclim.dataset_list")$variable == variable &
+      getOption("pastclim.dataset_list")$dataset == dataset
+  ])
 }
