@@ -49,7 +49,10 @@ region_slice <-
       ext = ext,
       crop = crop
     )
-    return(slice_region_series(x = this_series, time_bp = time_bp, time_ce = time_ce))
+    return(slice_region_series(
+      x = this_series, time_bp = time_bp,
+      time_ce = time_ce
+    ))
   }
 
 
