@@ -1,6 +1,7 @@
 # set up data path for this test
 data_path <- file.path(tempdir(), "pastclim_data")
-unlink(data_path, recursive = TRUE) # it should not exist, but remove it just in case
+# it should not exist, but remove it just in case
+unlink(data_path, recursive = TRUE)
 # set data path
 set_data_path(
   path_to_nc = data_path,
@@ -20,7 +21,9 @@ test_that("check_dataset_path errors", {
     check_dataset_path("custom", NULL),
     "you need to set path_to_nc if dataset='custom'"
   )
-  example_filename <- getOption("pastclim.dataset_list")$file_name[getOption("pastclim.dataset_list")$dataset == "Example"][1]
+  example_filename <- getOption("pastclim.dataset_list")$file_name[
+    getOption("pastclim.dataset_list")$dataset == "Example"
+  ][1] # nolint
   expect_true(check_dataset_path(
     "custom",
     file.path(
