@@ -1,6 +1,7 @@
 # set up data path for this test
 data_path <- file.path(tempdir(), "pastclim_data")
-unlink(data_path, recursive = TRUE) # it should not exist, but remove it just in case
+# it should not exist, but remove it just in case
+unlink(data_path, recursive = TRUE)
 # set data path
 set_data_path(
   path_to_nc = data_path,
@@ -12,7 +13,8 @@ set_data_path(
 
 test_that("get df from region series", {
   x <- region_series(
-    time_bp = list(min = -15000, max = 0), bio_variables = c("bio01", "bio10", "bio12"),
+    time_bp = list(min = -15000, max = 0),
+    bio_variables = c("bio01", "bio10", "bio12"),
     dataset = "Example"
   )
   df_series <- df_from_region_series(x, xy = TRUE)
