@@ -1,4 +1,5 @@
-# test that the files names generated for chelsa present do point to a valid file
+# test that the files names generated for chelsa present do point to a valid
+# file
 
 test_that("filenames_chelsa_present are correct", {
   skip_if_offline()
@@ -15,6 +16,7 @@ test_that("filenames_chelsa_present are correct", {
   bio_files <- filenames_chelsa_present(bio_var = "temperature_min_09")
   expect_true(url_is_valid(bio_files))
   bio_files <- filenames_chelsa_present(bio_var = "temperature_max_09")
-  expect_true(url_is_valid(bio_files))  
-}
-)
\ No newline at end of file
+  expect_true(url_is_valid(bio_files))
+  bio_files <- filenames_chelsa_present(bio_var = "npp")
+  expect_true(url_is_valid(bio_files))
+})
