@@ -1,6 +1,7 @@
 # set up data path for this test
 data_path <- file.path(tempdir(), "pastclim_data")
-unlink(data_path, recursive = TRUE) # it should not exist, but remove it just in case
+# it should not exist, but remove it just in case
+unlink(data_path, recursive = TRUE)
 # set data path
 set_data_path(
   path_to_nc = data_path,
@@ -109,7 +110,9 @@ test_that("location_series", {
 
 
   # now use a custom dataset
-  example_filename <- getOption("pastclim.dataset_list")$file_name[getOption("pastclim.dataset_list")$dataset == "Example"][1]
+  example_filename <- getOption("pastclim.dataset_list")$file_name[
+    getOption("pastclim.dataset_list")$dataset == "Example"
+  ][1] # nolint
   path_to_example_nc <- system.file("/extdata/", example_filename,
     package = "pastclim"
   )
